# LSB Test Execution Framework
# Samba test module
#
# Copyright (C) 2007 The Linux Foundation. All rights reserved.
#
# This program has been developed by ISP RAS for LF with some parts
# derived from lsb-autotest written by Jiri Dluhos <jdluhos@suse.cz>
# Copyright (C) 2005-2007 SuSE Linux Products GmbH
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

package Samba_test;
use strict;

use Common;
use Packages;

require Tests::Test_common;
@Samba_test::ISA = qw(Test_common);

=head ##
Class Samba_test Inherits Test_common;
=cut ##

sub new {
    my $self  = Test_common->new();
    $self->{NAME} = "samba";
    $self->{DISPLAYNAME} = "Samba Tests";
    $self->{DESCRIPTION} = "LSB Application Battery Functional Tests for Samba,"
        ." a file and print server for SMB/CIFS clients.";
    $self->{PACKAGES} .= " lsb-samba";
    $self->{SOURCES} .= " appbat";
    $self->{BETA_SOURCES} .= " appbat";

    bless($self);
    return $self;
}

sub run {
    my $self = shift;
    
    my $samba_started = 0;
    
    if ( cmd("ps -A | grep -e '\\bsmbd\$'") == 0 ) {
        $samba_started = 1;
    }
    
    if ($samba_started) {
        if ( -f "/etc/init.d/smb" ) {
            inform("Stop samba daemon");
            cmd("/etc/init.d/smb stop");
        }
        elsif ( -f "/etc/init.d/samba" ) {
            inform("Stop samba daemon");
            cmd("/etc/init.d/samba stop");
        }
    }

    my $result = Test_common::run($self);

    cmd("killall smbd");
    cmd("killall nmbd");

    if ($samba_started) {
        if ( -f "/etc/init.d/smb" ) {
            inform("Restart samba daemon");
            cmd("/etc/init.d/smb restart");
        }
        elsif ( -f "/etc/init.d/samba" ) {
            inform("Restart samba daemon");
            cmd("/etc/init.d/samba restart");
        }
    }
    return $result;
}

sub journal {
    my $self = shift;
    
    store_journal_info(
        "Certification Tests/Automated Application Battery Tests/Samba Tests"
        , "samba", "$results_dir/test_journals/samba.simplejournal", $self);
}

1; # return value